API Reference¶
The gamesheet_sdk package exposes Pythonic wrappers around the GameSheet platform. Complete API documentation for all modules, packages, and subpackages
is generated automatically from source on every documentation build using sphinx-apidoc.
The package is organized into three pillars:
common— Shared infrastructure (auth, config, session, browser, output, errors)admin— Admin dashboard domain modules and CLIteams— Teams dashboard domain modules and CLI
1. Module index¶
All Python modules are automatically discovered and documented. Click any module name to view its complete API documentation.
gamesheet_sdk — unofficial Python SDK for the GameSheet Inc. |
|
Shared infrastructure for the GameSheet SDK. |
|
Authentication flows and token management for GameSheet. |
|
Reusable Playwright browser session for the JS-heavy WebUI path. |
|
Shared CLI utilities for GameSheet CLIs. |
|
Configuration for an SDK session. |
|
SDK-wide constants and configuration values. |
|
Error message templates for the GameSheet SDK. |
|
Exceptions raised by gamesheet_sdk. |
|
Multi-format rendering of tabular data for CLI workflows. |
|
Security and file permission utilities. |
|
Reusable HTTP session for talking to the GameSheet WebUI. |
|
Shared utilities for domain modules. |
|
Admin dashboard SDK for GameSheet. |
|
GameSheet associations: the top-level organizational unit of the platform. |
|
GameSheet divisions: organizational groupings within a season. |
|
GameSheet games: scheduled, completed, and bracket games within a season. |
|
GameSheet iPad keys: Scoring Access Keys for season scoring via iPad app. |
|
GameSheet leagues: divisions within an association. |
|
GameSheet referees: officials assigned to games within a season. |
|
GameSheet roster: players and coaches within a season. |
|
GameSheet seasons: time periods within a league. |
|
Admin-specific shared utilities. |
|
GameSheet teams: competing organizations within a season. |
|
CLI for the GameSheet admin dashboard. |
|
Teams dashboard SDK for GameSheet. |
|
HTTP-only login flow for the GameSheet teams dashboard. |
|
Public lookup data from the teams API. |
|
Seasons data from the teams API. |
|
Authenticated session with automatic token refresh for the teams API gateway. |
|
Teams-specific shared utilities and constants. |
|
CLI for the GameSheet teams dashboard. |
2. Common infrastructure¶
Shared modules used by both admin and teams CLIs.
- gamesheet_sdk.common
- gamesheet_sdk.common.auth
- gamesheet_sdk.common.browser
- gamesheet_sdk.common.cli
- gamesheet_sdk.common.config
- gamesheet_sdk.common.constants
- gamesheet_sdk.common.errors
- gamesheet_sdk.common.exceptions
- gamesheet_sdk.common.output
- gamesheet_sdk.common.security
- gamesheet_sdk.common.session
- gamesheet_sdk.common.shared
- gamesheet_sdk.common.browser
- gamesheet_sdk.common.config
- gamesheet_sdk.common.constants
- gamesheet_sdk.common.errors
- gamesheet_sdk.common.exceptions
- gamesheet_sdk.common.output
- gamesheet_sdk.common.security
- gamesheet_sdk.common.session
3. Authentication package¶
Authentication flows, token management, and authenticated HTTP session.
- gamesheet_sdk.common.auth
- gamesheet_sdk.common.auth.constants module
- gamesheet_sdk.common.auth.credentials module
- gamesheet_sdk.common.auth.firebase module
- gamesheet_sdk.common.auth.flow module
- gamesheet_sdk.common.auth.login module
- gamesheet_sdk.common.auth.session module
- gamesheet_sdk.common.auth.storage module
- gamesheet_sdk.common.auth.tokens module
5. Common CLI infrastructure¶
Shared CLI framework used by both admin and teams CLIs.
- gamesheet_sdk.common.cli
ResourceGroupcolumns_option()common_output_options()confirm_destructive()emit_shell_completion()get_local_timezone_name()get_local_timezone_offset()parse_columns_spec()parse_flexible_datetime()render_get_command()render_list_command()render_penalty_report()resolve_create_times()resolve_datetime_input()resolve_exit()resolve_system_exit()resolve_update_times()run_action_or_exit()validate_end_after_start()validate_no_input_conflict()
- gamesheet_sdk.common.cli.constants module
- gamesheet_sdk.common.cli.core module
- gamesheet_sdk.common.cli.decorators module
- gamesheet_sdk.common.cli.helpers module
- gamesheet_sdk.common.cli.rendering module
- gamesheet_sdk.common.cli.rich_config module
6. Admin domain modules¶
Domain modules for the admin dashboard.
- gamesheet_sdk.admin
- gamesheet_sdk.admin.associations
- gamesheet_sdk.admin.cli
- gamesheet_sdk.admin.divisions
- gamesheet_sdk.admin.games
- gamesheet_sdk.admin.ipad_keys
- gamesheet_sdk.admin.leagues
- gamesheet_sdk.admin.referees
- gamesheet_sdk.admin.roster
- gamesheet_sdk.admin.seasons
- gamesheet_sdk.admin.shared
- gamesheet_sdk.admin.teams
- gamesheet_sdk.admin.associations
- gamesheet_sdk.admin.divisions
- gamesheet_sdk.admin.ipad_keys
- gamesheet_sdk.admin.leagues
- gamesheet_sdk.admin.referees
- gamesheet_sdk.admin.seasons
- gamesheet_sdk.admin.teams
7. Admin games package¶
Game retrieval and management for scheduled, completed, and bracket games.
- gamesheet_sdk.admin.games
BroadcasterGameGameDataLocationRelationshipRelationshipDataScheduledGameScheduledGameAttributesScheduledGameDataScheduledGameRelationshipsScorekeeperTeamInfocreate_scheduled_game()delete_scheduled_game()download_completed_game_pdf()get_completed_game()get_game()get_location()get_scheduled_game()list_brackets()list_broadcasters()list_completed()list_locations()list_scheduled()update_scheduled_game()validate_broadcaster_key()validate_game_type()validate_location()
- gamesheet_sdk.admin.games.brackets module
- gamesheet_sdk.admin.games.broadcasters module
- gamesheet_sdk.admin.games.completed module
- gamesheet_sdk.admin.games.helpers module
- gamesheet_sdk.admin.games.locations module
- gamesheet_sdk.admin.games.models module
- gamesheet_sdk.admin.games.scheduled module
8. Admin roster package¶
Player and coach roster management.
- gamesheet_sdk.admin.roster
CoachPlayerassign_coach()assign_player()assign_team_coach()assign_team_player()create_coach()create_player()create_team_coach()create_team_player()delete_coach()delete_player()delete_team_coach()delete_team_player()get_coach()get_coach_penalty_report()get_player()get_player_penalty_report()get_team_coach()get_team_player()list_coaches()list_players()list_team_coaches()list_team_players()unassign_coach()unassign_player()unassign_team_coach()unassign_team_player()update_coach()update_player()update_team_coach()update_team_player()
- gamesheet_sdk.admin.roster.coaches module
- gamesheet_sdk.admin.roster.helpers module
- gamesheet_sdk.admin.roster.models module
- gamesheet_sdk.admin.roster.players module
9. Admin CLI¶
Admin CLI framework and command implementations.
- gamesheet_sdk.admin.cli
- gamesheet_sdk.admin.cli.constants module
- gamesheet_sdk.admin.cli.helpers module
- gamesheet_sdk.admin.cli.main module
- gamesheet_sdk.admin.cli.shared package
columns_option()common_output_options()get_local_timezone_name()get_local_timezone_offset()parse_flexible_datetime()player_update_options()render_get_command()render_list_command()render_penalty_report()resolve_create_times()resolve_datetime_input()resolve_update_times()team_create_options()team_update_options()validate_end_after_start()validate_no_input_conflict()- Submodules
- gamesheet_sdk.admin.cli.shared.datetime_helpers module
- gamesheet_sdk.admin.cli.shared.decorators module
- gamesheet_sdk.admin.cli.shared.rendering module
- gamesheet_sdk.admin.cli.commands package
- gamesheet_sdk.admin.cli.commands.associations module
- gamesheet_sdk.admin.cli.commands.completion module
- gamesheet_sdk.admin.cli.commands.divisions module
- gamesheet_sdk.admin.cli.commands.games module
- gamesheet_sdk.admin.cli.commands.games_brackets module
- gamesheet_sdk.admin.cli.commands.games_completed module
- gamesheet_sdk.admin.cli.commands.games_scheduled module
- gamesheet_sdk.admin.cli.commands.ipad_keys module
- gamesheet_sdk.admin.cli.commands.leagues module
- gamesheet_sdk.admin.cli.commands.locations module
- gamesheet_sdk.admin.cli.commands.login module
- gamesheet_sdk.admin.cli.commands.referees module
- gamesheet_sdk.admin.cli.commands.roster module
- gamesheet_sdk.admin.cli.commands.roster_coaches module
- gamesheet_sdk.admin.cli.commands.roster_players module
- gamesheet_sdk.admin.cli.commands.seasons module
- gamesheet_sdk.admin.cli.commands.teams module
- gamesheet_sdk.admin.cli.commands.teams_roster module
- gamesheet_sdk.admin.cli.commands.teams_roster_coaches module
- gamesheet_sdk.admin.cli.commands.teams_roster_players module
10. Teams domain and CLI¶
Teams domain models, auth, and CLI command implementations.
- gamesheet_sdk.teams
CalendarEventCreatedCalendarSubscriptionCreatedGameResultLookupValuePenaltyCodeScheduleDeleteResultScheduleEventScheduleEventDetailSeasonDetailSeasonSummarySeasonTeamTeamDetailTeamSummaryTeamsAuthenticatedSessionTeamsLoginFlowUpdatedGameResultarchive_team()build_rrule()create_calendar_event_raw()create_event()create_game()create_practice()create_schedule_game_raw()delete_calendar_event()delete_calendar_event_raw()delete_calendar_occurrence()delete_calendar_occurrence_raw()delete_event()delete_game()delete_practice()delete_schedule_game_raw()delete_team()fetch_availability_raw()fetch_calendar_raw()fetch_event_occurrence_raw()fetch_scheduled_game_raw()fetch_seasons_raw()fetch_team_raw()fetch_teams_raw()get_calendar_subscription()get_event()get_game()get_practice()get_schedule_event()get_season()get_season_penalty_codes()get_season_teams()get_team()list_events()list_games()list_lookups()list_practices()list_schedule()list_seasons()list_teams()refresh_access_token()restore_team()unarchive_team()update_calendar_occurrence()update_calendar_occurrence_raw()update_event()update_game()update_practice()update_schedule_game_raw()update_team()upload_team_image()validate_game_type()
- gamesheet_sdk.teams.login
- gamesheet_sdk.teams.lookups
- gamesheet_sdk.teams.seasons
- gamesheet_sdk.teams.session
- gamesheet_sdk.teams.teams module
- gamesheet_sdk.teams.shared
- gamesheet_sdk.teams.shared.constants module
TEAMS_API_GATEWAYFIREBASE_API_KEYTEAMS_TOKEN_EXCHANGE_PATHTEAMS_REFRESH_PATHTEAMS_LOOKUPS_PATHTEAMS_SEASONS_PATHTEAMS_TEAMS_PATHTEAMS_CALENDAR_PATHTEAMS_CALENDAR_EVENTS_PATHTEAMS_CALENDAR_OCCURRENCES_PATHTEAMS_SCHEDULE_GAME_PATHTEAMS_AVAILABILITY_BATCH_PATHTEAMS_IMAGES_UPLOAD_URL_PATHTEAMS_PUBLIC_CALENDAR_SERVICE
- gamesheet_sdk.teams.cli
- gamesheet_sdk.teams.cli.helpers module
- gamesheet_sdk.teams.cli.main module
- gamesheet_sdk.teams.cli.commands package
- gamesheet_sdk.teams.cli.commands.completion module
- gamesheet_sdk.teams.cli.commands.login module
- gamesheet_sdk.teams.cli.commands.lookups module
- gamesheet_sdk.teams.cli.commands.seasons module
- gamesheet_sdk.teams.cli.commands.teams module